Hello community,

here is the log from the commit of package python-virtinst for openSUSE:Factory 
checked in at 2013-06-07 10:08:29
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/python-virtinst (Old)
 and      /work/SRC/openSUSE:Factory/.python-virtinst.new (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "python-virtinst"

Changes:
--------
--- /work/SRC/openSUSE:Factory/python-virtinst/python-virtinst.changes  
2013-02-05 11:20:01.000000000 +0100
+++ /work/SRC/openSUSE:Factory/.python-virtinst.new/python-virtinst.changes     
2013-06-07 10:08:30.000000000 +0200
@@ -1,0 +2,34 @@
+Fri May 31 15:01:12 MDT 2013 - [email protected]
+
+- Renamed all patches ending with '.diff' to '.patch'.
+
+-------------------------------------------------------------------
+Sat May 25 15:47:39 MDT 2013 - [email protected]
+
+- bnc#821331 - virt-manager doesn't create correct cloned qcow2 or
+  vmdk image configuration when cloning a domu
+  virtinst-clone-disks.diff
+
+-------------------------------------------------------------------
+Tue May  7 17:53:14 MDT 2013 - [email protected]
+
+- bnc#811831 - s390x KVM Unable to complete install: 'Couldn't find
+  hvm kernel for SUSE tree.
+  virtinst-s390x-media-paths.diff
+
+-------------------------------------------------------------------
+Fri May  3 17:43:27 MDT 2013 - [email protected]
+
+- bnc#813082 - virt-manager doesn't create correct XML for the new
+  qcow2 or vmdk disk on xen host - Revisited for Xen HVM guests
+  virtinst-xen-drive-type.diff
+
+-------------------------------------------------------------------
+Tue Apr  2 15:03:36 MDT 2013 - [email protected]
+
+- Update to virtinst 0.600.4
+  * virt-install: New convenience option --controller usb2
+  * API support for disk iotune properties (David Shane Holden)
+  * Bug fixes and minor improvements
+
+-------------------------------------------------------------------

Old:
----
  virtinst-0.600.3.tar.bz2
  virtinst-add-cache-modes.diff
  virtinst-cdrom.diff
  virtinst-git-lun.diff
  virtinst-qed.diff
  virtinst-storage-ocfs2.diff

New:
----
  virtinst-0.600.4.tar.bz2
  virtinst-add-cache-modes.patch
  virtinst-cdrom.patch
  virtinst-clone-disks.patch
  virtinst-qed.patch
  virtinst-s390x-media-paths.patch
  virtinst-storage-ocfs2.patch
  virtinst-xen-drive-type.patch

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ python-virtinst.spec ++++++
--- /var/tmp/diff_new_pack.0hJ0TY/_old  2013-06-07 10:08:31.000000000 +0200
+++ /var/tmp/diff_new_pack.0hJ0TY/_new  2013-06-07 10:08:31.000000000 +0200
@@ -37,14 +37,16 @@
 Group:          System/Monitoring
 
 Name:           python-%{appname}
-Version:        0.600.3
+Version:        0.600.4
 Release:        0
 Source0:        %{appname}-%{version}.tar.bz2
-Patch0:         virtinst-git-lun.diff
-Patch10:        virtinst-cdrom.diff
-Patch12:        virtinst-storage-ocfs2.diff
-Patch13:        virtinst-qed.diff
-Patch14:        virtinst-add-cache-modes.diff
+Patch10:        virtinst-cdrom.patch
+Patch12:        virtinst-storage-ocfs2.patch
+Patch13:        virtinst-qed.patch
+Patch14:        virtinst-add-cache-modes.patch
+Patch15:        virtinst-xen-drive-type.patch
+Patch16:        virtinst-s390x-media-paths.patch
+Patch17:        virtinst-clone-disks.patch
 
 BuildRoot:      %{_tmppath}/%{name}-%{version}-build
 #BuildArch: noarch
@@ -76,11 +78,13 @@
 
 %prep
 %setup -q -n %{appname}-%{version}
-%patch0 -p1
 %patch10 -p1
 %patch12 -p1
 %patch13 -p1
 %patch14 -p1
+%patch15 -p1
+%patch16 -p1
+%patch17 -p1
 
 %build
 python setup.py build

++++++ virtinst-0.600.3.tar.bz2 -> virtinst-0.600.4.tar.bz2 ++++++
/work/SRC/openSUSE:Factory/python-virtinst/virtinst-0.600.3.tar.bz2 
/work/SRC/openSUSE:Factory/.python-virtinst.new/virtinst-0.600.4.tar.bz2 
differ: char 11, line 1

++++++ virtinst-add-cache-modes.patch ++++++
Index: virtinst-0.600.4/virtinst/VirtualDisk.py
===================================================================
--- virtinst-0.600.4.orig/virtinst/VirtualDisk.py
+++ virtinst-0.600.4/virtinst/VirtualDisk.py
@@ -301,10 +301,13 @@ class VirtualDisk(VirtualDevice):
     driver_types = [DRIVER_TAP_RAW, DRIVER_TAP_QCOW,
         DRIVER_TAP_QED, DRIVER_TAP_VMDK, DRIVER_TAP_VDISK]
 
+    CACHE_MODE_DIRECTSYNC = "directsync"
     CACHE_MODE_NONE = "none"
+    CACHE_MODE_UNSAFE = "unsafe"
     CACHE_MODE_WRITETHROUGH = "writethrough"
     CACHE_MODE_WRITEBACK = "writeback"
-    cache_types = [CACHE_MODE_NONE, CACHE_MODE_WRITETHROUGH,
+    cache_types = [CACHE_MODE_DIRECTSYNC, CACHE_MODE_NONE,
+        CACHE_MODE_UNSAFE, CACHE_MODE_WRITETHROUGH,
         CACHE_MODE_WRITEBACK]
 
     DEVICE_DISK = "disk"
@@ -588,7 +591,7 @@ class VirtualDisk(VirtualDevice):
         @type bus: C{str}
         @param shareable: If disk can be shared among VMs
         @type shareable: C{bool}
-        @param driverCache: Disk cache mode (none, writethrough, writeback)
+        @param driverCache: Disk cache mode (none, directsync, unsafe, 
writethrough, writeback)
         @type driverCache: member of cache_types
         @param selinuxLabel: Used for labelling new or relabel existing storage
         @type selinuxLabel: C{str}
++++++ virtinst-cdrom.patch ++++++
Index: virtinst-0.600.4/virtinst/VirtualDisk.py
===================================================================
--- virtinst-0.600.4.orig/virtinst/VirtualDisk.py
+++ virtinst-0.600.4/virtinst/VirtualDisk.py
@@ -1840,7 +1840,7 @@ class VirtualDisk(VirtualDevice):
         if maxnode > (26 * 26 * 26):
             raise RuntimeError("maxnode value is too high")
 
-        # Regular scanning
+        # Start cdrom at 'c' and skip 'c' for non-cdrom
         for i in range(1, maxnode + 1):
             gen_t = prefix
 
@@ -1866,8 +1866,14 @@ class VirtualDisk(VirtualDevice):
             if gen_t in except_targets:
                 continue
             if gen_t not in skip_targets:
-                self.target = gen_t
-                return self.target
+                if self.device != self.DEVICE_CDROM:
+                    if i != ord('c') - ord('a'):
+                        self.target = gen_t
+                        return self.target
+                else:
+                    if i >= ord('c') - ord('a'):
+                        self.target = gen_t
+                        return self.target
 
         # Check except_targets for any options
         for t in except_targets:
++++++ virtinst-clone-disks.patch ++++++
Index: virtinst-0.600.4/virtinst/CloneManager.py
===================================================================
--- virtinst-0.600.4.orig/virtinst/CloneManager.py
+++ virtinst-0.600.4/virtinst/CloneManager.py
@@ -519,6 +519,7 @@ class CloneDesign(object):
             xmldisk.type = clone_disk.type
             xmldisk.path = clone_disk.path
             xmldisk.driver_type = orig_disk.driver_type
+            xmldisk.driver_name = orig_disk.driver_name
 
         # Save altered clone xml
         self._clone_xml = self._guest.get_xml_config()
Index: virtinst-0.600.4/virtinst/VirtualDisk.py
===================================================================
--- virtinst-0.600.4.orig/virtinst/VirtualDisk.py
+++ virtinst-0.600.4/virtinst/VirtualDisk.py
@@ -1225,6 +1225,10 @@ class VirtualDisk(VirtualDevice):
             if _util.is_vdisk(self.path):
                 drvname = self.DRIVER_TAP
                 drvtype = self.DRIVER_TAP_VDISK
+            elif drvname is None and drvtype:
+                drvtypes = ['qcow2', 'vmdk']
+                if drvtype in drvtypes:
+                    drvname = 'tap'
 
         return drvname or None, drvtype or None
 
@@ -1602,6 +1606,8 @@ class VirtualDisk(VirtualDevice):
             if drvxml and self.driver_name is None:
                 if self.is_qemu():
                     self.driver_name = "qemu"
+                else:
+                    self.driver_name = self.get_driver_name()
 
             if not self.driver_name is None:
                 drvxml = (" name='%s'" % self.driver_name) + drvxml
++++++ virtinst-qed.patch ++++++
Index: virtinst-0.600.4/virtinst/VirtualDisk.py
===================================================================
--- virtinst-0.600.4.orig/virtinst/VirtualDisk.py
+++ virtinst-0.600.4/virtinst/VirtualDisk.py
@@ -295,10 +295,11 @@ class VirtualDisk(VirtualDevice):
 
     DRIVER_TAP_RAW = "aio"
     DRIVER_TAP_QCOW = "qcow"
+    DRIVER_TAP_QED = "qed"
     DRIVER_TAP_VMDK = "vmdk"
     DRIVER_TAP_VDISK = "vdisk"
     driver_types = [DRIVER_TAP_RAW, DRIVER_TAP_QCOW,
-        DRIVER_TAP_VMDK, DRIVER_TAP_VDISK]
+        DRIVER_TAP_QED, DRIVER_TAP_VMDK, DRIVER_TAP_VDISK]
 
     CACHE_MODE_NONE = "none"
     CACHE_MODE_WRITETHROUGH = "writethrough"
Index: virtinst-0.600.4/virtinst/ImageParser.py
===================================================================
--- virtinst-0.600.4.orig/virtinst/ImageParser.py
+++ virtinst-0.600.4/virtinst/ImageParser.py
@@ -204,6 +204,7 @@ class Disk:
     FORMAT_ISO = "iso"
     FORMAT_QCOW = "qcow"
     FORMAT_QCOW2 = "qcow2"
+    FORMAT_QED = "qed"
     FORMAT_VMDK = "vmdk"
     FORMAT_VDI = "vdi"
 
@@ -235,6 +236,7 @@ class Disk:
         formats = [Disk.FORMAT_RAW,
                    Disk.FORMAT_QCOW,
                    Disk.FORMAT_QCOW2,
+                   Disk.FORMAT_QED,
                    Disk.FORMAT_VMDK,
                    Disk.FORMAT_ISO,
                    Disk.FORMAT_VDI]
Index: virtinst-0.600.4/virtconv/diskcfg.py
===================================================================
--- virtinst-0.600.4.orig/virtconv/diskcfg.py
+++ virtinst-0.600.4/virtconv/diskcfg.py
@@ -37,6 +37,7 @@ DISK_FORMAT_QCOW = 4
 DISK_FORMAT_QCOW2 = 5
 DISK_FORMAT_COW = 6
 DISK_FORMAT_VDI = 7
+DISK_FORMAT_QED = 8
 
 DISK_TYPE_DISK = 0
 DISK_TYPE_CDROM = 1
@@ -53,6 +54,7 @@ disk_suffixes = {
     DISK_FORMAT_QCOW2: ".qcow2",
     DISK_FORMAT_COW: ".cow",
     DISK_FORMAT_VDI: ".vdi",
+    DISK_FORMAT_QED: ".qed",
 }
 
 qemu_formats = {
@@ -63,6 +65,7 @@ qemu_formats = {
     DISK_FORMAT_QCOW2: "qcow2",
     DISK_FORMAT_COW: "cow",
     DISK_FORMAT_VDI: "vdi",
+    DISK_FORMAT_QED: "qed",
 }
 
 disk_format_names = {
@@ -74,6 +77,7 @@ disk_format_names = {
     "qcow2": DISK_FORMAT_QCOW2,
     "cow": DISK_FORMAT_COW,
     "vdi": DISK_FORMAT_VDI,
+    "qed": DISK_FORMAT_QED,
 }
 
 checksum_types = {
@@ -265,7 +269,8 @@ class disk(object):
             out_format == DISK_FORMAT_VMDK or
             out_format == DISK_FORMAT_QCOW or
             out_format == DISK_FORMAT_QCOW2 or
-            out_format == DISK_FORMAT_COW):
+            out_format == DISK_FORMAT_COW or
+            out_format == DISK_FORMAT_QED):
             raise NotImplementedError(_("Cannot convert to disk format %s") %
                 output_format)
 
Index: virtinst-0.600.4/virtconv/parsers/virtimage.py
===================================================================
--- virtinst-0.600.4.orig/virtconv/parsers/virtimage.py
+++ virtinst-0.600.4/virtconv/parsers/virtimage.py
@@ -248,6 +248,7 @@ class virtimage_parser(formats.parser):
                 ImageParser.Disk.FORMAT_QCOW: diskcfg.DISK_FORMAT_QCOW,
                 ImageParser.Disk.FORMAT_QCOW2: diskcfg.DISK_FORMAT_QCOW2,
                 ImageParser.Disk.FORMAT_VDI: diskcfg.DISK_FORMAT_VDI,
+                ImageParser.Disk.FORMAT_QED: diskcfg.DISK_FORMAT_QED,
             }
 
             fmt = None
++++++ virtinst-s390x-media-paths.patch ++++++
Index: virtinst-0.600.4/virtinst/Storage.py
===================================================================
--- virtinst-0.600.4.orig/virtinst/Storage.py
+++ virtinst-0.600.4/virtinst/Storage.py
@@ -533,7 +533,7 @@ class FilesystemPool(StoragePool):
     get_volume_class = staticmethod(get_volume_class)
 
     formats = [ "auto", "ext2", "ext3", "ext4", "ufs", "iso9660", "udf",
-                "gfs", "gfs2", "vfat", "hfs+", "xfs" ]
+                "gfs", "gfs2", "vfat", "hfs+", "xfs", "ocfs2" ]
 
     # Register applicable property methods from parent class
     perms = property(StorageObject.get_perms, StorageObject.set_perms)
++++++ virtinst-xen-drive-type.patch ++++++
Reference: bnc#813082

Index: virtinst-0.600.4/virtinst/VirtualDisk.py
===================================================================
--- virtinst-0.600.4.orig/virtinst/VirtualDisk.py
+++ virtinst-0.600.4/virtinst/VirtualDisk.py
@@ -1199,6 +1199,11 @@ class VirtualDisk(VirtualDevice):
             if drvname == self.DRIVER_QEMU:
                 drvtype = _qemu_sanitize_drvtype(self.type, self.format,
                                                  manual_format=True)
+            else:
+                drvtype = self.format
+                drvtypes = ['qcow2', 'vmdk']
+                if drvtype in drvtypes and drvname is None:
+                    drvname = 'tap'
 
         elif self.vol_object:
             fmt = _util.get_xml_path(self.vol_object.XMLDesc(0),
Index: virtinst-0.600.4/virtinst/OSDistro.py
===================================================================
--- virtinst-0.600.4.orig/virtinst/OSDistro.py
+++ virtinst-0.600.4/virtinst/OSDistro.py
@@ -678,16 +678,22 @@ class SuseDistro(Distro):
             oldkern += "64"
             oldinit += "64"
 
-        # Tested with Opensuse >= 10.2, 11, and sles 10
-        self._hvm_kernel_paths = [ ("boot/%s/loader/linux" % self.arch,
-                                    "boot/%s/loader/initrd" % self.arch) ]
-        # Tested with Opensuse 10.0
-        self._hvm_kernel_paths.append(("boot/loader/%s" % oldkern,
-                                       "boot/loader/%s" % oldinit))
+        if self.arch == "s390x":
+            self._hvm_kernel_paths = [ ("boot/%s/vmrdr.ikr" % self.arch,
+                                        "boot/%s/initrd" % self.arch) ]
+            # No Xen on s390x
+            self._xen_kernel_paths = []
+        else:
+            # Tested with Opensuse >= 10.2, 11, and sles 10
+            self._hvm_kernel_paths = [ ("boot/%s/loader/linux" % self.arch,
+                                        "boot/%s/loader/initrd" % self.arch) ]
+            # Tested with Opensuse 10.0
+            self._hvm_kernel_paths.append(("boot/loader/%s" % oldkern,
+                                           "boot/loader/%s" % oldinit))
 
-        # Matches Opensuse > 10.2 and sles 10
-        self._xen_kernel_paths = [ ("boot/%s/vmlinuz-xen" % self.arch,
-                                    "boot/%s/initrd-xen" % self.arch) ]
+            # Matches Opensuse > 10.2 and sles 10
+            self._xen_kernel_paths = [ ("boot/%s/vmlinuz-xen" % self.arch,
+                                        "boot/%s/initrd-xen" % self.arch) ]
 
     def isValidStore(self, fetcher, progresscb):
         # Suse distros always have a 'directory.yast' file in the top
++++++ virtinst-storage-ocfs2.patch ++++++
-- 
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]

Reply via email to